DeviceHelper class

DeviceHelper stores device information related to device ScreenType and Orientation

Constructors

DeviceHelper()

Properties

deviceInfoModel → DeviceInfoModel
no setter
hashCode → int
The hash code for this object.
no setterinherited
isLandscape → bool
no setter
isLargeScreen → bool
no setter
isTablet → bool
no setter
orientation → Orientation
no setter
platFormText → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenOrientationString → String
no setter
screenType → EScreenType
no setter
screenTypeString → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDeivceInfo(BuildContext context, BoxConstraints constraints, Orientation currentOrientation) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getInstance() → DeviceHelper